function [playerAdvantage] = advSingleHand(deck,strategy);
%
% Computes player's advantage per hand, given the distribution of the deck,
% and the player's strategy.
% 
% Must call setupVariables.m before running this function.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Blackjack Markov Chain Toolbox, v1.0 (08 Jan 2009)
%%% 
%%% Companion to manuscript 
%%%    "A Markov Chain Analysis of Blackjack Strategy"
%%%    by Michael B. Wakin and Christopher J. Rozell, 2004.
%%%    available at: http://inside.mines.edu/~mwakin/papers/mcbj.pdf
%%%
%%% Software Copyright 2009 by 
%%%    Michael B. Wakin, Colorado School of Mines, mwakin@mines.edu
%%%    Christopher J. Rozell, Georgia Tech, crozell@gatech.edu 
%%%
%%% This software is released under a Creative Commons license
%%% (Attribution 3.0 Unported): 
%%%     http://creativecommons.org/licenses/by/3.0/
%%% You are free:
%%%    * to Share  to copy, distribute and transmit the work
%%%    * to Remix  to adapt the work
%%% Under the following conditions:
%%%   * You must attribute the work by retaining this header information
%%%     crediting the original authors and linking to the original
%%%     manuscript.
%%%   * For any reuse or distribution, you must make clear to others the 
%%%     license terms of this work.
%%%   * Any of the above conditions can be waived if you get permission 
%%%     from the copyright holder.
%%%   * Nothing in this license impairs or restricts the author's 
%%%     moral rights.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Setup global variables
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global PLAYERfirst PLAYERstartHard PLAYERmidHard PLAYERstartSoft PLAYERmidSoft PLAYERstartPair PLAYERterm PLAYERdoubTerm PLAYERtermSplit PLAYERblackjack PLAYERsurrender PLAYERbust PLAYERdoubBust

global DEALERfirst DEALERhard DEALERsoft DEALERterm DEALERblackjack DEALERbust

global Pinf PSinf PDinf 

%%%%%%%%%%%%%%%%%%%%
%%% Preliminaries
%%%%%%%%%%%%%%%%%%%%

% Normalize deck probabilities to sum to one.
deck = deck/sum(deck);

% Put ace probability in both slots 1 and 11.
deck(11) = deck(1);

%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Transition Matrices
%%%%%%%%%%%%%%%%%%%%%%%%%%

% Build player's transition matrix, and multiply to get absorbing states.
calcPlayerTrans(deck,strategy);

% Build player's transition matrix for a post-split hand
calcPlayerTransSplit(deck,strategy);

% Build dealer's transition matrix, and multiply to get absorbing states.
calcDealerTrans(deck);

%%%%%%%%%%%%%%%%%%%%%%%%
%%% Compute advantage
%%%%%%%%%%%%%%%%%%%%%%%%

% Calculate profits given that dealer starts with each card (2 through 11)
dProfits = zeros(1,11);

% Initialize
splitProfits = zeros(1,11);

for dCard = 2:11    
  if (deck(dCard) > 0)
    % In this iteration, calculate profit given that dealer starts with dCard
    
    % Distribution on the dealer's termination states
    pdRow = PDinf(DEALERfirst(dCard),:);

    % Distribution on the player's termination states
    pRow = zeros(1,PLAYERdoubBust);
    for pCard = 2:11
      pRow = pRow + deck(pCard)*squeeze(Pinf(dCard,PLAYERfirst(pCard),:))'; 
    end

    % If the dealer has blackjack, the player does not get to play the rest
    % of the hand, and so the Markov analysis is not relevant
    probDealerBJ = pdRow(DEALERblackjack);
    
    % Let's go ahead and compute the profit if dealer starts with blackjack
    %   Player has blackjack (push)
    profitDealerBJ = 0;    
    %   Player has no blackjack (lose 1)
    profitDealerBJ = profitDealerBJ + (-1)*(1-pRow(PLAYERblackjack));

    % Now compute the distribution of the dealer's states conditioned on 
    % the dealer having no blackjack. For the rest of the analysis, we can
    % assume the dealer does not have blackjack.
    pdRowNoBJ = pdRow;
    pdRowNoBJ(DEALERblackjack) = 0;
    pdRowNoBJ = pdRowNoBJ/sum(pdRowNoBJ);
    
    % To compute the player's advantage, we must know how much he would
    % profit on each possible split. 
    for ii = 2:11
      % Terminal distribution, after starting split with card ii.
      pRowSplit = PSinf(dCard,PLAYERfirst(ii),:);
      % Find profits when player terminates
      splitProfits(ii) = computeTermProfit(pRowSplit,pdRowNoBJ);
    end
    % Now we can compute the player's advantage on the initial hand
    profitNoDealerBJ = computeTermProfit(pRow,pdRowNoBJ);
    % ...and we add in profits from split plays (computed above)
    for ii = 2:11
      profitNoDealerBJ = profitNoDealerBJ + 2*pRow(PLAYERtermSplit(ii))*splitProfits(ii);
    end
    
    % Combine profits (conditioning on whether dealer has blackjack)
    dProfits(dCard) = probDealerBJ*profitDealerBJ + (1-probDealerBJ)*profitNoDealerBJ;  
    
  end
end

% Finally, weight each profit by the probability that the dealer 
% starts with dCard
playerAdvantage = sum(dProfits.*deck);
